{% extends "admin/base_site.html" %}
{% load adminmedia %}
{% load i18n %}

{% block extrastyle %}
    {{ block.super }}
    <link rel="stylesheet" type="text/css" href="{% admin_media_prefix %}css/documentation.css" />
{% endblock %}{% block coltype %}colSM{% endblock %}
{% block bodyclass %}dashboard documentation{% endblock %}
{% block breadcrumbs %}<div class="breadcrumbs"><a href="/admin/">{% trans "Home" %}</a> &rsaquo; {% trans "Help" %}</div>{% endblock %}

{% block content %}
<div id="content-main" class="rte">
    <div class="module">
        <p>{% trans "This section should explain the handling of the Admin-Interface/CMS. Permissions provided, you can change/add entries to this Section." %}</p>
    </div>
</div>
{% endblock %}

{% block sidebar %}
<div id="content-related" style="float: left !important;">
    {% for help in menu %}
    <div class="module">
        <table>
            <caption style="width:100%;">{{ help }}</caption>
            {% for helpitem in help.helpitem_set.all %}
            <tr class="collapse">
                <th scope="row"><a href="{{ helpitem.id }}/">{{ helpitem }}</a></th>
                <td>&nbsp;</td>
                <td>&nbsp;</td>
            </tr>
            {% endfor %}
        </table>
    </div>
    {% endfor %}
</div>
{% endblock %}
