


/*  Basic Settings
------------------------------------------------------------------------------------------------------ */

.module > h2, .module caption, 
.inline-group h2,
.inline-related h2 {
    margin: 0; padding: 7px 5px 6px 10px;
    color: #444; font-size: 12px; line-height: 16px; font-weight: bold;
    border-bottom: 1px solid #d4d4d4;
    -moz-border-radius-topleft: 4px; -webkit-border-top-left-radius: 4px; border-top-left-radius: 4px;
    -moz-border-radius-topright: 4px; -webkit-border-top-right-radius: 4px; border-top-right-radius: 4px;
    background-color: #e6e6e6;
}
.inline-related h3, 
.inline-related h4 {
    -moz-border-radius-topleft: 4px; -webkit-border-top-left-radius: 4px; border-top-left-radius: 4px;
    -moz-border-radius-topright: 4px; -webkit-border-top-right-radius: 4px; border-top-right-radius: 4px;
}
.module caption a:link, .module caption a:visited {
    color: #444;
}
.module caption a:hover, .module caption a:active {
    color: #3da8cc;
}



/*  Modules
------------------------------------------------------------------------------------------------------ */

.module {
    margin-bottom: 5px;
    border: 1px solid #d4d4d4;
    -moz-border-radius: 5px; -webkit-border-radius: 5px; border-radius: 5px;
    background: #fff;
}
#content-main .module, 
#content .module {
    background: #eee;
}
#content-related .module, 
#content-related-extended .module {
    background: #fff;
}


/*  Collapsible Modules ................................................... */

.module.collapsed {
    border: 1px solid #d4d4d4;
}
.module.collapsed:hover, .module.collapse-open {
    border: 1px solid #c4c4c4;
}



/*  Collapsible Basics
------------------------------------------------------------------------------------------------------ */

h2.collapse-toggle, 
h3.collapse-toggle, 
h4.collapse-toggle {
    display: block;
    color: #444 !important;
    background-repeat: no-repeat;
    cursor: pointer;
}
.collapse-closed > .collapse-toggle {
    -moz-border-radius: 4px; -webkit-border-radius: 4px; border-radius: 4px;
    background-position: 0 100%;
}
fieldset.collapse-closed > .collapse-toggle, 
.inline-related.collapse-closed > .collapse-toggle {
    border-bottom: none;
}
.collapse-closed > .collapse-toggle:hover, .collapse-open > .collapse-toggle {
    background-position: 0 0;
}
.collapse-open > .collapse-toggle {
    border-bottom: 1px solid #ccc;
}



/*  Collapsible Fieldsets
------------------------------------------------------------------------------------------------------ */

fieldset.collapse-closed {
    display: block;
}
fieldset.collapse-closed div {
    display: none;
}


/*  H2 in Fieldsets ................................................... */

fieldset.module > h2 {
    margin: 0; padding-left: 15px;
    border-bottom: 1px solid #d4d4d4;
    background-color: #e0e0e0;
}

fieldset.collapse-closed h2.collapse-toggle {
    background-color: #e0f0f5;
    background-image: url('../img/icons/icon_fieldset_collapse-closed.png');
}
fieldset.collapse-closed h2.collapse-toggle:hover, 
fieldset.collapse-open h2.collapse-toggle {
    background-color: #c0e1ec;
    background-image: url('../img/icons/icon_fieldset_collapse-open.png');
}



/*  Inline Group
------------------------------------------------------------------------------------------------------ */

.inline-group.collapse-closed .items {
    display: none;
}

.inline-group {
    position: relative;
    margin: 6px 0 7px; padding: 2px;
    border: 2px solid #b3b3b3;
    -moz-border-radius: 7px; -webkit-border-radius: 7px; border-radius: 7px;
    background: #fff;
}
.inline-group.collapse-closed {
    border-color: #d4d4d4;
}


/*  H2 in Inline-Group ................................................... */

.inline-group h2 {
    padding-left: 11px !important;
    border: 1px solid #c4c4c4;
    -moz-border-radius: 5px; -webkit-border-radius: 5px; border-radius: 5px;
    background-color: #e0e0e0;
}
.inline-group.collapse-closed h2.collapse-toggle {
    border-color: #d4d4d4;
    background-color: #d6ebf2;
    background-image: url('../img/icons/icon_fieldset_collapse-closed.png');
}
.inline-group.collapse-closed h2.collapse-toggle:hover, 
.inline-group.collapse-open h2.collapse-toggle {
    border-color: #c4c4c4;
    background-color: #c0e1ec;
    background-image: url('../img/icons/icon_fieldset_collapse-open.png');
}



/*  Inline-Related Fieldsets
----------------------------------------------------------------------- */

.inline-related.collapsed fieldset {
    display: none;
}

.inline-related {
    position: relative; display: block;
    margin: 3px 0 0; padding: 0;
    border: 1px solid #d4d4d4;
    -moz-border-radius: 5px; -webkit-border-radius: 5px; border-radius: 5px;
}
.inline-related.collapse-closed:hover, 
.inline-related.collapse-open {
    border-color: #c4c4c4;
}
.inline-related .module {
    margin-bottom: 0;
    border: none;
}

.inline-related .module.collapse-closed, 
.inline-related .module.collapse-open {
    margin: 1px -1px -1px;
    border: 1px solid;
    -moz-border-radius-topleft: 0; -webkit-border-top-left-radius: 0; border-top-left-radius: 0;
    -moz-border-radius-topright: 0; -webkit-border-top-right-radius: 0; border-top-right-radius: 0;
}
.inline-related .module.collapse-closed, 
.inline-related .module.collapse-closed:hover, 
.inline-related .module.collapse-open {
    border-color: #c4c4c4;
    border-top-color: #e0e0e0;
    background: #fff !important;
}

.inline-related h3 + * + .module {
    border-top: 1px solid #fff;
    -moz-border-radius-topleft: 0; -webkit-border-top-left-radius: 0; border-top-left-radius: 0;
    -moz-border-radius-topright: 0; -webkit-border-top-right-radius: 0; border-top-right-radius: 0;
}


/*  H3 in Inline-Related ................................................... */

.inline-related h3 {
    padding: 5px 5px 4px 11px;
    color: #444; font-size: 11px; line-height: 15px; font-weight: bold;
}
.inline-related.collapse-closed h3.collapse-toggle {
    background-color: #eff5e4;
    background-image: url('../img/icons/icon_fieldset_collapse-closed.png');
}
.inline-related.collapse-closed h3.collapse-toggle:hover, 
.inline-related h3.collapse-toggle {
    background-color: #e0ebca;
    background-image: url('../img/icons/icon_fieldset_collapse-open.png');
}


/*  H4 in Inline-Related > Fieldset ................................................... */

.inline-related fieldset h4 {
    margin: 1px; padding: 5px 5px 4px 9px;
    color: #444; font-size: 11px; line-height: 15px; font-weight: bold;
}
.inline-related fieldset.collapse-closed h4.collapse-toggle {
    border: 1px solid #d4d4d4;
    background-color: #d6ebf2;
    background-image: url('../img/icons/icon_fieldset_collapse-closed.png');
}
.inline-related fieldset.collapse-closed h4.collapse-toggle:hover, 
.inline-related h4.collapse-toggle {
    border: 1px solid #d4d4d4;
    background-color: #c0e1ec;
    background-image: url('../img/icons/icon_fieldset_collapse-open.png');
}



/*  Inline-Related Tabular
------------------------------------------------------------------------------------------------------ */

.inline-group.collapsed .legend {
    display: none;
}
.inline-group.inline-tabular {
    padding-bottom: 0;
}
.inline-group.inline-tabular.collapse-closed {
    padding-bottom: 2px;
}
.inline-tabular .items, 
.inline-tabular .predelete-items {
    display: table;
    border-collapse: separate;
    border-spacing: 0 2px;
}
@media screen and (-webkit-min-device-pixel-ratio:0) {
    .inline-group.inline-tabular {
        padding-bottom: 1px;
    }
    .inline-tabular .items, 
    .inline-tabular .predelete-items {
        border-spacing: 0 1px;
    }
}
.inline-tabular .inline-related {
    width: 100%;
    background: transparent;
    display: table-row-group;
}
.inline-tabular .legend {
    display: table-header-group;
    margin: 5px 0 0;
    color: #aaa; font-size: 11px; font-weight: bold;
}

.inline-tabular .fieldset.module {
    display: table-row;
}
.inline-tabular .form-cell {
    display: table-cell; overflow: hidden;
    padding: 5px 10px;
    height: 100%;
    vertical-align: top;
    white-space: nowrap;
    border-top: 1px solid #d4d4d4;
    border-bottom: 1px solid #d4d4d4;
    border-right: 1px solid #e0e0e0;
    border-left: 1px solid #fff;
    background: #eee;
}
.inline-tabular .legend .form-cell {
    padding: 2px 10px 0;
    border: none;
    border-left: 1px solid #fff;
    border-right: 1px solid #e0e0e0;
    background: transparent;
}
.inline-tabular .legend .form-cell:last-child {
    border-right: none;
    -moz-border-radius-topright: 5px; -webkit-border-top-right-radius: 5px; border-top-right-radius: 5px;
    -moz-border-radius-bottomright: 5px; -webkit-border-bottom-right-radius: 5px; border-bottom-right-radius: 5px;
}
.inline-tabular .fieldset .form-cell:first-child {
    border-left: 1px solid #ccc;
    -moz-border-radius-topleft: 5px; -webkit-border-top-left-radius: 5px; border-top-left-radius: 5px;
    -moz-border-radius-bottomleft: 5px; -webkit-border-bottom-left-radius: 5px; border-bottom-left-radius: 5px;
}


/*  UI Sortable: Placeholder & Sortable Helper ----------------------- */

.inline-group.collapsed .items {
    display: none;
}
.placeholder {
    margin: 5px 0;
    height: 40px !important;
}
.inline-tabular .placeholder {
    display: table-row-group;
    border-spacing: 0 !important;
}
.inline-tabular .placeholder div {
    display: table-row;
    height: 30px !important;
    border-spacing: 0 !important;
}
.sortablehelper {
    position: absolute; top: -1000px; left: 19px; display: block;
    margin: 0; padding: 0;
    color: #666;
}
.sortablehelper h3 {
    margin: 0 !important; padding: 5px 0 4px 37px;
    color: #fff; font-size: 12px; line-height: 15px;
    -moz-border-radius: 5px; -webkit-border-radius: 5px; border-radius: 5px;
    background: #65a3c2;
}


/*  Inline-Related Predelete ----------------------- */

.inline-tabular .predelete .form-cell, 
.inline-stacked .predelete, 
.inline-stacked .predelete h3 {
    background-color: #f2d6d6 !important;
}

.inline-tabular .predelete .fieldset.module {
    border-color: #e5caca;
}
.inline-tabular .predelete .form-cell {
    border-left-color: #ffe5e5;
    border-right-color: #e5caca;
}



/*  Inline-Item Tools
------------------------------------------------------------------------------------------------------ */

ul.inline-item-tools {
    display: block;
    position: absolute;
    margin: 0; padding: 0;
}
ul.inline-item-tools li {
    float: left;
    margin: 0; padding: 0;
    font-weight: bold;
}
ul.inline-item-tools li:last-child {
    border-right: none;
}


/*  Inline-Group > H2 ................................................... */

.inline-group h2 + ul.inline-item-tools, 
.inline-group.collapse-closed h2:hover + ul.inline-item-tools {
    top: 3px; right: 7px;
}
.inline-group h2 + ul.inline-item-tools li, 
.inline-group.collapse-closed h2:hover + ul.inline-item-tools li {
    top: 3px;
    width: 20px; height: 29px;
}


/*  Inline-Related > H3 ................................................... */

.inline-related h3 + ul.inline-item-tools, 
.inline-related.collapse-closed h3:hover + ul.inline-item-tools {
    top: 0; right: 4px;
}
.inline-related h3 + ul.inline-item-tools li, 
.inline-related.collapse-closed h3:hover + ul.inline-item-tools li {
    top: 2px;
    width: 20px; height: 24px;
}


/*  Form-Cell ................................................... */

.inline-tabular .fieldset .form-cell.inline-item-tools {
    position: relative;
    margin: 0; padding: 0;
    width: 100%;
    text-align: right;
    -moz-border-radius-topright: 5px; -webkit-border-top-right-radius: 5px; border-top-right-radius: 5px;
    -moz-border-radius-bottomright: 5px; -webkit-border-bottom-right-radius: 5px; border-bottom-right-radius: 5px;
}

.form-cell ul.inline-item-tools {
    display: inline-block;
    position: relative;
    margin: 0 4px -4px 0;
    border-left-color: #d4d4d4;
}

.form-cell ul.inline-item-tools li {
    display: inline-block;
    position: relative;
    width: 20px; height: 35px;
    border-left-color: #fff;
    border-right-color: #d4d4d4;
}


/*  Links ................................................... */

.inline-group ul.inline-item-tools a {
    position: relative; display: block;
    padding: 0;
    width: 100%; height: 100%;
    font-size: 11px; line-height: 13px;
    background-position: 50% 50%;
    background-repeat: no-repeat;
}

ul.inline-item-tools li:last-child a, 
.inline-related.collapsed ul.inline-item-tools li:last-child a {
    border-right: none;
    -moz-border-radius-topright: 3px; -webkit-border-top-right-radius: 3px; border-top-right-radius: 3px;
    -moz-border-radius-bottomright: 3px; -webkit-border-bottom-right-radius: 3px; border-bottom-right-radius: 3px;
}
.inline-related ul.inline-item-tools li:last-child a {
    -moz-border-radius-bottomright: 3px; -webkit-border-bottom-right-radius: 3px; border-bottom-right-radius: 3px;
}


/*  Icons ................................................... */

ul.inline-item-tools a.draghandler:link, ul.inline-item-tools a.draghandler:visited {
    background-image: url('../img/icons/icon-inline_item_tools-draghandler.png');
}
ul.inline-item-tools a.draghandler:hover, ul.inline-item-tools a.draghandler:active {
    background-image: url('../img/icons/icon-inline_item_tools-draghandler-hover.png');
}
.predelete-items a.draghandler, .predelete-item a.draghandler {
    display: none;
}

ul.inline-item-tools a.viewsitelink:link, ul.inline-item-tools a.viewsitelink:visited {
    background-image: url('../img/icons/icon-inline_item_tools-viewsitelink.png');
}
ul.inline-item-tools a.viewsitelink:hover, ul.inline-item-tools a.viewsitelink:active {
    background-image: url('../img/icons/icon-inline_item_tools-viewsitelink-hover.png');
}

ul.inline-item-tools a.deletelink:link, ul.inline-item-tools a.deletelink:visited, 
.predelete ul.inline-item-tools a.deletelink:hover, .predelete ul.inline-item-tools a.deletelink:active {
    background-image: url('../img/icons/icon-inline_item_tools-deletelink.png');
}
ul.inline-item-tools a.deletelink:hover, ul.inline-item-tools a.deletelink:active, 
.predelete ul.inline-item-tools a.deletelink:link, .predelete ul.inline-item-tools a.deletelink:visited {
    background-image: url('../img/icons/icon-inline_item_tools-deletelink-hover.png');
}

ul.inline-item-tools a.addhandler:link, ul.inline-item-tools a.addhandler:visited {
    background-image: url('../img/icons/icon-inline_item_tools-addhandler.png');
}
ul.inline-item-tools a.addhandler:hover, ul.inline-item-tools a.addhandler:active {
    background-image: url('../img/icons/icon-inline_item_tools-addhandler-hover.png');
}

ul.inline-item-tools a.openhandler:link, ul.inline-item-tools a.openhandler:visited {
    background-image: url('../img/icons/icon-inline_item_tools-openhandler.png');
}
ul.inline-item-tools a.openhandler:hover, ul.inline-item-tools a.openhandler:active {
    background-image: url('../img/icons/icon-inline_item_tools-openhandler-hover.png');
}

ul.inline-item-tools a.closehandler:link, ul.inline-item-tools a.closehandler:visited {
    background-image: url('../img/icons/icon-inline_item_tools-closehandler.png');
}
ul.inline-item-tools a.closehandler:hover, ul.inline-item-tools a.closehandler:active {
    background-image: url('../img/icons/icon-inline_item_tools-closehandler-hover.png');
}


