{% load i18n %}
<div class="changelist-actions actions">
    {% for field in action_form %}<label>{{ field }}</label>{% endfor %}
    {% if actions_selection_counter %}
        <script type="text/javascript">var _actions_icnt="{{ cl.result_list|length|default:"0" }}";</script>
        <ul>
            <li class="action-counter"><span class="action-counter">{{ selection_note }}</span></li>
            {% if cl.result_count != cl.result_list|length %}
                <li class="all"><span class="all">{{ selection_note_all }}</span></li>
                <li class="question"><a href="javascript:;" title="{% trans "Click here to select the objects across all pages" %}">{% blocktrans with cl.result_count as total_count %}Select all {{ total_count }} {{ module_name }}{% endblocktrans %}</a></li>
                <li class="clear-selection"><a href="javascript://" class="clear">{% trans "Clear selection" %}</a></li>
            {% endif %}
        </ul>
    {% endif %}
</div>