


/*  Changelist
------------------------------------------------------------------------------------------------------ */

#changelist {
    position: relative;
}
#changelist.module {
    border: none;
    background-color: #fff;
}
#changelist.module.filtered {
    padding-right: 212px;
}

#changelist .result-list-container {
    border: 1px solid #d4d4d4;
    -moz-border-radius: 5px; -webkit-border-radius: 5px; border-radius: 5px;
    background: #eee;
}

#changelist .result-list {
    border-top: 1px solid #fff;
    border-bottom: 1px solid #d4d4d4;
}
#changelist .result-list:first-child {
    border-top: none;
    -moz-border-radius-topleft: 5px; -webkit-border-top-left-radius: 5px; border-top-left-radius: 5px;
}



/*  Changelist Filtered
------------------------------------------------------------------------------------------------------ */

#changelist.filtered .changelist-content {
    position: relative; float: left;
    margin-right: 10px;
    width: 100%;
}
#changelist-filter {
    position: relative; float: left;
    margin-right: -10000px;
    width: 200px;
    border-right: none;
}

#changelist.filtered table, 
#changelist.filtered .actions, 
#changelist.filtered .paginator, 
#changelist.filtered .submit-row {
    width: auto;
}

#changelist.filtered .submit-row {
    margin: 10px 0; padding: 0;
    border: none;
}

.changelist-actions li.all,
.changelist-actions li.clear-selection,
.changelist-actions li.question {
   display: none;
}


/*  Changelist Table
------------------------------------------------------------------------------------------------------ */

#changelist table {
    margin-top: -1px;
    margin-right: -1px;
    border-right: 1px solid #d4d4d4;
}
#changelist tbody th, #changelist tbody td {
    border: none;
    border-top: 1px solid #e8e8e8;
    border-left: 1px solid #e0e0e0;
}
#changelist tbody tr:first-child th, #changelist tbody tr:first-child td {
    border-top: 1px solid #fff;
}
#changelist tbody tr th:first-child, #changelist tbody tr td:first-child {
    border-left: none;
}

#changelist .result-list:first-child table {
    margin-top: 0;
    border-top: none;
}
#changelist .result-list:first-child thead th:first-child a {
    -moz-border-radius-topleft: 5px; -webkit-border-top-left-radius: 5px; border-top-left-radius: 5px;
}
#changelist .result-list:first-child thead th:last-child a {
    -moz-border-radius-topright: 5px; -webkit-border-top-right-radius: 5px; border-top-right-radius: 5px;
}
#changelist table:first-child thead th, 
#changelist form > input + table thead th {
    border-top: none;
}
#changelist table:first-child thead th:first-child, 
#changelist form > input + table thead th:first-child {
    -moz-border-radius-topleft: 5px; -webkit-border-top-left-radius: 5px; border-top-left-radius: 5px;
}

#changelist form table tbody td, #changelist form table tbody th {
    padding-top: 10px;
    padding-bottom: 9px;
    line-height: 16px;
}



/*  Actions
------------------------------------------------------------------------------------------------------ */

#changelist .actions {
    color: #666;
    padding: 5px 3px;
    border-top: 1px solid #fff;
    border-bottom: 1px solid #d4d4d4;
}
#changelist .actions:first-child {
    border-top: none;
}

#changelist .actions select {
    margin-left: 0;
}

#changelist .actions label {
    font-weight: bold; overflow: visible;
    margin: -2px 0 -2px 5px; padding: 5px 0 7px 25px;
    background: transparent url('../img/icons/icon-actions_changelist.png') 0 50% no-repeat;
}

#changelist #action-toggle {
    display: none;
}
#changelist .actions select {
    width: 408px;
}


/*  Paginator
------------------------------------------------------------------------------------------------------ */

.paginator {
    margin: 0; padding: 10px 12px;
    font-size: 11px; font-weight: bold;
    overflow: hidden;
    border-top: 1px solid #fff;
}
.paginator:first-child {
    border-top: none;
}
.paginator .separator {
    position: relative; display: inline-block;
    top: -11px; margin: 0 8px -24px;
    width: 0px; height: 40px;
    border-left: 1px solid #ddd;
    border-right: 1px solid #f4f4f4;
}

.paginator span {
    margin: 0 8px;
}
.paginator span.separator + span {
    margin-left: 0;
}
.paginator a.end {
    margin-right: 4px;
}
.paginator a.showall {
    margin-right: 15px;
}
.paginator a:link, .paginator a:visited {
    padding: 4px 8px;
    font-size: 11px; font-weight: bold;
    border: 1px solid #ccc;
    border-color: #ccc #ddd #ddd #ccc;
    -moz-border-radius: 3px; -webkit-border-radius: 3px; border-radius: 3px;
    background: #fff;
}
.paginator a:hover, .paginator a:active {
    color: #fff;
    background: #3da8cc;
}



/*  Changelist-Filter Basic Settings
------------------------------------------------------------------------------------------------------ */

#changelist-filter .module {
    margin-bottom: 10px;
}
#changelist-filter .form-row {
    padding: 5px 10px;
}
#changelist-filter .form-row.narrow {
    padding: 3px 10px;
}

#changelist-filter h2 {
    margin: 0;
    font-size: 12px;
    border-bottom: 1px solid #d4d4d4;
    -moz-border-radius-topleft: 4px; -webkit-border-top-left-radius: 4px; border-top-left-radius: 4px;
    -moz-border-radius-topright: 4px; -webkit-border-top-right-radius: 4px; border-top-right-radius: 4px;
    background-color: #e0e0e0;
}

#changelist-filter a {
    display: block;
    font-size: 11px; line-height: 13px; font-weight: bold;
}
#changelist-filter a:link, #changelist-filter a:visited {
    color: #59afcc;
}
#changelist-filter a:hover, #changelist-filter a:active, 
#changelist-filter .selected a {
    color: #444;
}



/*  Results (Search)
------------------------------------------------------------------------------------------------------ */

#changelist .results p {
    margin: 5px 0 2px;
    font-weight: bold; line-height: 12px;
}
#changelist .results span.full-result-count {
    font-size: 10px;
}



/*  Toolbar (Search)
------------------------------------------------------------------------------------------------------ */

#changelist #toolbar {
    border-top: 1px solid #fff;
}
#changelist #toolbar p.help  {
    margin: 0 0 2px;
    line-height: 12px;
}



/*  Top Links (xfull, Date Hierarchy)
------------------------------------------------------------------------------------------------------ */

ul.date_hierarchy {
    border-top: 1px solid #fff;
}



/*  Filterset
------------------------------------------------------------------------------------------------------ */

#changelist-filter .filterset h3 {
    margin: 0; padding: 5px 10px 4px;
    font-size: 11px; line-height: 14px;
    -moz-border-radius: 0; -webkit-border-radius: 0; border-radius: 0;
    cursor: pointer;
}
#changelist .filterset h3.form-row {
    border-top: 1px solid #f5fdff;
    border-bottom: 1px solid #d1e1e5;
    background: #e0f0f5;
}
#changelist .filterset h3.form-row:hover, 
#changelist .filterset.collapse-open h3.form-row {
    border-top: 1px solid #dceff5;
    border-bottom: 1px solid #cadbe0;
    background: #c0e1ec;
}
#changelist-filter .filterset.collapse-closed:last-child h3 {
    border-bottom: none;
    -moz-border-radius-bottomleft: 4px; -webkit-border-bottom-left-radius: 4px; border-bottom-left-radius: 4px;
    -moz-border-radius-bottomright: 4px; -webkit-border-bottom-right-radius: 4px; border-bottom-right-radius: 4px;
}


/*  UL Filterset (Listing of Filters) ................................................... */

#changelist-filter .filterset.collapse-closed ul {
    display: none;
}
#changelist-filter .filterset.collapse-open ul {
    display: block;
    border-top: 1px solid #fff;
    border-bottom: 1px solid #e0e0e0;
}
#changelist-filter ul li:last-child, 
#changelist-filter ul li:last-child *, 
#changelist-filter .filterset:last-child ul {
    border-bottom: none;
    -moz-border-radius-bottomleft: 4px; -webkit-border-bottom-left-radius: 4px; border-bottom-left-radius: 4px;
    -moz-border-radius-bottomright: 4px; -webkit-border-bottom-right-radius: 4px; border-bottom-right-radius: 4px;
}



/*  Unknown, Yes & No Workaround
------------------------------------------------------------------------------------------------------ */

img[src$="img/admin/icon-unknown.gif"] {
    padding: 5px;
    width: 0; height: 0;
    background: url('../img/icons/icon-unknown.png') 0 50% no-repeat;
}
img[src$="img/admin/icon-no.gif"] {
    padding: 5px;
    width: 0; height: 0;
    background: url('../img/icons/icon-no.png') 0 50% no-repeat;
}
img[src$="img/admin/icon-yes.gif"] {
    padding: 5px;
    width: 0; height: 0;
    background: url('../img/icons/icon-yes.png') 0 50% no-repeat;
}

.change-list form table img[src$="img/admin/icon-unknown.gif"] {
    position: relative; top: 2px;
    vertical-align: top;
}
.change-list form table img[src$="img/admin/icon-no.gif"] {
    position: relative; top: 3px;
    vertical-align: top;
}
.change-list form table img[src$="img/admin/icon-yes.gif"] {
    position: relative; top: 2px;
    vertical-align: top;
}

