{% extends "admin/base_site.html" %}
{% load adminmedia %}
{% load i18n %}
{% block stylesheets %}
    {{ block.super }}
    <link rel="stylesheet" type="text/css" href="{% admin_media_prefix %}css/documentation.css" />
{% endblock %}
{% block extrahead %}
<script>
$(document).ready(function(){
    // Correct the position of anchors (because "#header" & "#breadcrumbs" have a "position:fixed")
    $('#content-related a').click(function(){
        var myReference = "#content-main " + $(this).attr('href');
        var targetOffset = $(myReference).offset().top;
        $('html,body').scrollTop(targetOffset - 60);
        return(false);
    });
});
</script>
{% endblock %}
{% block bodyclass %}documentation{% endblock %}
{% block coltype %}colSM{% endblock %}
{% block breadcrumbs %}<div class="breadcrumbs"><a href="../../">Home</a> &rsaquo; <a href="../">Documentation</a> &rsaquo; Views</div>{% endblock %}
{% block title %}Views{% endblock %}

{% block content %}

<h1>View documentation</h1>

{% regroup views|dictsort:"site_id" by site as views_by_site %}

<div id="content-related" class="sidebar">
<div class="module">
<h2>Jump to site</h2>
<ul>
    {% for site_views in views_by_site %}
    <li><a href="#site{{ site_views.grouper.id }}">{{ site_views.grouper.name }}</a></li>
    {% endfor %}
</ul>
</div>
</div>

<div id="content-main" class="rte">

{% for site_views in views_by_site %}
<div class="module">
<h2 id="site{{ site_views.grouper.id }}">Views by URL on {{ site_views.grouper.name }}</h2>

{% for view in site_views.list|dictsort:"url" %}
{% ifchanged %}
<h3><a href="{{ view.module }}.{{ view.name }}/">{{ view.url }}</a></h3>
<p class="small quiet">View function: {{ view.module }}.{{ view.name }}</p>
<p>{{ view.title }}</p>
<hr />
{% endifchanged %}
{% endfor %}
</div>
{% endfor %}
</div>
{% endblock %}


