{% extends "admin/base_site.html" %}
{% load adminmedia %}
{% load i18n %}
{% block stylesheets %}
    {{ block.super }}
    <link rel="stylesheet" type="text/css" href="{% admin_media_prefix %}css/documentation.css" />
{% endblock %}
{% block bodyclass %}documentation{% endblock %}
{% block breadcrumbs %}<div class="breadcrumbs"><a href="{{ root_path }}">Home</a> &rsaquo; Documentation</div>{% endblock %}
{% block title %}Documentation{% endblock %}

{% block content %}

<h1>Documentation</h1>

<div id="content-main" class="rte">
    <div class="module">
        <h2><a href="tags/">Tags</a></h2>
        <p>List of all the template tags and their functions.</p>
    </div>
    <div class="module">
        <h2><a href="filters/">Filters</a></h2>
        <p>Filters are actions which can be applied to variables in a template to alter the output.</p>
    </div>
    <div class="module">
        <h2><a href="models/">Models</a></h2>
        <p>Models are descriptions of all the objects in the system and their associated fields. Each model has a list of fields which can be accessed as template variables.</p>
    </div>
    <div class="module">
        <h2><a href="views/">Views</a></h2>
        <p>Each page on the public site is generated by a view. The view defines which template is used to generate the page and which objects are available to that template.</p>
    </div>
    <div class="module">
        <h2><a href="bookmarklets/">Bookmarklets</a></h2>
        <p>Tools for your browser to quickly access admin functionality.</p>
    </div>
</div>

{% endblock %}

