{% load i18n %}

{% if choices.0.selected %}
<div class="filterset collapse-closed">
{% else %}
<div class="filterset collapse-open">
{% endif %}
    <h3 class="form-row">{% blocktrans with title as filter_title %} By {{ filter_title }} {% endblocktrans %}</h3>
    <ul>
    {% for choice in choices %}
        <li class="form-row narrow{% if choice.selected %} selected{% endif %}">
        <a href="{{ choice.query_string|iriencode }}">{{ choice.display|safe }}</a></li>
    {% endfor %}
    </ul>
</div>
