{% extends "admin/base_site.html" %}
{% load i18n future grp_csrf %}
{% block userlinks %}
{% url "django-admindocs-docroot" as docsroot %}{% if docsroot %}
<li>
    <a href="{{ docsroot }}">{% trans 'Documentation' %}</a>
</li>
{% endif %}
<li>
    <a href="{{ root_path }}password_change/">{% trans 'Change password' %}</a>
</li>
<li>
    <a href="{{ root_path }}logout/">{% trans 'Log out' %}</a>
</li>
{% endblock %}

{% block title %}{% trans 'Password change' %}{% endblock %}

{% block content %}

<h1>{% trans 'Password change' %}</h1>

<p>{% trans "Please enter your old password, for securitys sake, and then enter your new password twice so we can verify you typed it in correctly." %}</p>

<form action="" method="post">{% grp_csrf_token %}
    <div>
        <fieldset class="module aligned">
            <div class="form-row">
                {{ form.old_password.errors }}
                <label for="id_old_password" class="required">{% trans 'Old password:' %}</label>{{ form.old_password }}
            </div>
            <div class="form-row">
                {{ form.new_password1.errors }}
                <label for="id_new_password1" class="required">{% trans 'New password:' %}</label>{{ form.new_password1 }}
            </div>
            <div class="form-row">
                {{ form.new_password2.errors }}
                <label for="id_new_password2" class="required">{% trans 'Confirm password:' %}</label>{{ form.new_password2 }}
            </div>
        </div>
        <div class="submit-row"><input type="submit" value="{% trans 'Change my password' %}" class="default" /></div>
    </div>
</form>

{% endblock %}
